@@ -81,6 +81,9 @@ You may turn off/on adding newlines by passing ``newlines=False`` or
    >>> print h
    <ol><li>item 1</li><li>item 2</li></ol>
 
+That control is also available as the ``newlines`` attribute on the
+``HTML`` or tag instance if you need to alter it after instantiation.
+
 Since we can't use ``class`` as a keyword, the library recognises ``klass``
 as a substitute::
 
@@ -105,12 +108,27 @@ Rendering doesn't affect the HTML document's state, so you can add to or
 otherwise manipulate the HTML after you've stringified it.
 
 
+Creating XHTML
+--------------
+
+To construct XHTML start with an instance of ``html.XHTML()`` and use it
+as you would an ``HTML`` instance. Empty elements will now be rendered
+with the appropriate XHTML minimized tag syntax. For example::
+
+   >>> from html import XHTML
+   >>> h = XHTML()
+   >>> h.p
+   >>> h.br
+   >>> print h
+   <p></p>
+   <br />
+
 ----
 
 This code is copyright 2009 eKit.com Inc (http://www.ekit.com/)
 See the end of the source file for the license of use.
 '''
-__version__ = '1.4'
+__version__ = '1.5'
 
 import unittest
 import cgi
@@ -188,18 +206,65 @@ class HTML(object):
             s += join + '</%s>'%self.name
         return s
 
+class XHTML(HTML):
+    '''Easily generate XHTML.
+
+    '''
+    
+    empty_elements = set('base meta link hr br param img area input col \
+        colgroup basefont isindex frame'.split())
+    
+    def __getattr__(self, name):
+        # adding a new tag or newline
+        if name == 'newline':
+            e = '\n'
+        else:
+            e = XHTML(name, self.stack)
+        if self.top:
+            self.stack[-1].content.append(e)
+        else:
+            self.content.append(e)
+        return e
+    def __str__(self):
+        # turn me and my content into text
+        # honor empty and non-empty elements
+        join = '\n' if self.newlines else ''
+        if self.name is None:
+            return join.join(map(str, self.content))
+        a = ['%s="%s"'%i for i in self.attrs.items()]
+        l = [self.name] + a
+        s = '<%s>%s'%(' '.join(l), join)
+        if self.content or not(self.name.lower() in self.empty_elements):
+            s += join.join(map(str, self.content))   
+            s += join + '</%s>'%self.name
+        else:
+            s = '<%s />%s'%(' '.join(l), join)
+        return s
+
 class TestCase(unittest.TestCase):
     def test_empty_tag(self):
-        'generation of an empty tag'
+        'generation of an empty HTML tag'
         h = HTML()
         h.br
         self.assertEquals(str(h), '<br>')
+
+    def test_empty_tag(self):
+        'generation of an empty XHTML tag'
+        h = XHTML()
+        h.br
+        self.assertEquals(str(h), '<br />')
+ 
+    def test_xhtml_match_tag(self):
+        'check forced generation of matching tag when empty'
+        self.assertEquals(str(XHTML().p), '<p></p>')
  
     def test_just_tag(self):
-        'generate the HTML for just one tag'
-        h = HTML()
-        h.br
-        self.assertEquals(str(h.br), '<br>')
+        'generate HTML for just one tag'
+        self.assertEquals(str(HTML().br), '<br>')
+
+    def test_just_tag_xhtml(self):
+        'generate XHTML for just one tag'
+        self.assertEquals(str(XHTML().br), '<br />')
 
     def test_para_tag(self):
         'generation of a tag with contents'
@@ -222,8 +287,8 @@ class TestCase(unittest.TestCase):
     def test_escape_attr(self):
         'escaping of special HTML characters in attributes'
         h = HTML()
-        h.a(a='<>&"')
-        self.assertEquals(str(h), '<a a="&lt;&gt;&amp;&quot;">')
+        h.br(id='<>&"')
+        self.assertEquals(str(h), '<br id="&lt;&gt;&amp;&quot;">')
 
     def test_subtag_context(self):
         'generation of sub-tags using "with" context'
@@ -298,7 +363,6 @@ class TestCase(unittest.TestCase):
 <tr><td>column 1</td><td>column 2</td></tr>
 </table>''')
 
-
 if __name__ == '__main__':
     unittest.main()
 
